summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsbindingplugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jsbindingplugin.h')
-rw-r--r--kjsembed/jsbindingplugin.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kjsembed/jsbindingplugin.h b/kjsembed/jsbindingplugin.h
index 6d54a508..fb7d6361 100644
--- a/kjsembed/jsbindingplugin.h
+++ b/kjsembed/jsbindingplugin.h
@@ -39,14 +39,14 @@ namespace KJSEmbed {
* @author Ian Reinhart Geiser, geiseri@kde.org
* @version $Id$
*/
- class KJSEMBED_EXPORT JSBindingPlugin : public TTQObject {
+ class KJSEMBED_EXPORT JSBindingPlugin : public TQObject {
Q_OBJECT
public:
- JSBindingPlugin( TTQObject *parent, const char *name, const TTQStringList &args );
+ JSBindingPlugin( TQObject *parent, const char *name, const TQStringList &args );
virtual ~JSBindingPlugin();
/**
* This method is called by the KJSFactory to bootstrap the plugin.
* Plugin developers will want to use this method to create their TTQObject binding,
* or call their addBindings() method in their JSOpaque proxy or JSValueProxy.
*
* The value returned from ths function is the KJS::Object that represents the
@@ -39,14 +39,14 @@ namespace KJSEmbed {
/**
* This method is called by the KJSFactory to bootstrap the plugin.
- * Plugin developers will want to use this method to create their TTQObject binding,
+ * Plugin developers will want to use this method to create their TQObject binding,
* or call their addBindings() method in their JSOpaque proxy or JSValueProxy.
*